__title__ = "kakao.py"
__author__ = "jhleekr"
__license__ = "MIT"
__copyright__ = "Copyright (C) 2021 jhleekr"
__version__ = "0.2.0"

from .kakao import Client
from .checkreg import check_reg
from .ext import commands